traitsui\.tests\.editors\.test\_code\_editor module
===================================================

.. automodule:: traitsui.tests.editors.test_code_editor
    :members:
    :undoc-members:
    :show-inheritance:
